### Prerequistes and Dependencies
Needs python and node.js.

- Uses Decktape: https://github.com/astefanutti/decktape

To install decktape, run in osd-slides.
```sh
$ npm install decktape
```
You will need node.js on your computer for above to run.
Check if node.js in your computer by running this. And then check the version of npm.
You might want to restart your terminal/powershell after installing node.js.
```sh
$ Node --version
$ npm --version
```

### Opening a PR
- Before opening a PR make sure all the tests pass by running:
```sh
$ make test
```

### Possible Areas Contribute
- Add more tests to cover functions
- In Search class there are many random tags that get read into self.text. It would be helpful for someone to clean those.